Skip to content

Most article formats are based on rmarkdown::pdf_document(), with a custom Pandoc LaTeX template and different default values for other arguments (e.g., keep_tex = TRUE).

Usage

acm_article(...)

acs_article(
  ...,
  keep_tex = TRUE,
  md_extensions = c("-autolink_bare_uris"),
  fig_caption = TRUE
)

aea_article(..., keep_tex = TRUE, md_extensions = c("-autolink_bare_uris"))

agu_article(
  ...,
  keep_tex = TRUE,
  citation_package = "natbib",
  highlight = NULL,
  md_extensions = c("-autolink_bare_uris", "-auto_identifiers")
)

amq_article(
  ...,
  latex_engine = "xelatex",
  keep_tex = TRUE,
  fig_caption = TRUE,
  md_extensions = c("-autolink_bare_uris")
)

asa_article(..., keep_tex = TRUE, citation_package = "natbib")

arxiv_article(..., keep_tex = TRUE)

bioinformatics_article(..., keep_tex = TRUE, citation_package = "natbib")

biometrics_article(..., keep_tex = TRUE, citation_package = "natbib")

ctex_article(..., template = "default", latex_engine = "xelatex")

ctex(..., template = "default", latex_engine = "xelatex")

elsevier_article(
  ...,
  keep_tex = TRUE,
  md_extensions = c("-autolink_bare_uris"),
  citation_package = "natbib"
)

frontiers_article(..., keep_tex = TRUE, citation_package = "natbib")

glossa_article(..., keep_tex = TRUE, latex_engine = "xelatex")

ims_article(
  journal = c("aoas", "aap", "aop", "aos", "sts"),
  keep_tex = TRUE,
  citation_package = "natbib",
  md_extensions = c("-autolink_bare_uris"),
  pandoc_args = NULL,
  ...
)

informs_article(..., keep_tex = TRUE, citation_package = "natbib")

iop_article(..., keep_tex = TRUE, citation_package = "natbib")

jasa_article(
  ...,
  keep_tex = TRUE,
  latex_engine = "xelatex",
  citation_package = "natbib"
)

lipics_article(
  ...,
  latex_engine = "pdflatex",
  keep_tex = TRUE,
  citation_package = "natbib",
  md_extensions = c("-autolink_bare_uris", "-auto_identifiers")
)

lncs_article(..., keep_tex = TRUE, citation_package = c("default", "natbib"))

jedm_article(..., keep_tex = TRUE, citation_package = "natbib")

mnras_article(..., keep_tex = TRUE, fig_caption = TRUE)

peerj_article(..., keep_tex = TRUE)

pihph_article(
  ...,
  keep_tex = TRUE,
  latex_engine = "xelatex",
  citation_package = "biblatex"
)

plos_article(..., keep_tex = TRUE, md_extensions = c("-autolink_bare_uris"))

pnas_article(..., keep_tex = TRUE)

sage_article(..., highlight = NULL, citation_package = "natbib")

sim_article(
  ...,
  highlight = NULL,
  citation_package = "natbib",
  latex_engine = "xelatex"
)

springer_article(
  ...,
  keep_tex = TRUE,
  citation_package = "natbib",
  number_sections = TRUE,
  latex_engine = "pdflatex",
  pandoc_args = NULL
)

trb_article(..., keep_tex = TRUE, citation_package = "natbib")

wellcomeor_article(
  ...,
  number_sections = FALSE,
  keep_tex = TRUE,
  citation_package = "natbib"
)

isba_article(
  ...,
  keep_tex = TRUE,
  highlight = NULL,
  citation_package = "natbib"
)

Arguments

..., number_sections, keep_tex, latex_engine, citation_package, highlight, fig_caption, md_extensions, template, pandoc_args

Arguments passed to rmarkdown::pdf_document().

journal

one of "aoas", "aap", "aop", "aos", "sts" for ims_article

Value

An R Markdown output format.

Details

You can find more details about each output format below.

acm_article

Format for creating an Association for Computing Machinery (ACM) articles. Adapted from https://www.acm.org/publications/proceedings-template.

acs_article

Format for creating an American Chemical Society (ACS) Journal articles. Adapted from https://pubs.acs.org/page/4authors/submission/tex.html

aea_article

Format for creating submissions to the American Economic Association (AER, AEJ, JEL, PP).

agu_article

Format for creating a American Geophysical Union (AGU) article. Adapted from https://www.agu.org/publications.

amq_article

Ce format a été adapté du format du bulletin de l'AMQ.

asa_article

This format was adapted from The American Statistician (TAS) format, but it should be fairly consistent across American Statistical Association (ASA) journals.

arxiv_article

Adapted from the George Kour's format for arXiv and bio-arXiv preprints. So far as I'm aware, entirely unofficial but still a staple.

bioinformatics_article

Format for creating submissions to a Bioinformatics journal. Adapted from https://academic.oup.com/bioinformatics/pages/submission_online.

biometrics_article

This format was adapted from the Biometrics journal.

ctex_article

A wrapper function for rmarkdown::pdf_document() and the default value of latex_engine is changed to xelatex, so it works better for typesetting Chinese documents with the LaTeX package ctex. The function ctex is an alias of ctex_article.

elsevier_article

Format for creating submissions to Elsevier journals. Adapted from https://www.elsevier.com/researcher/author/policies-and-guidelines/latex-instructions.

It requires a minimum version of 2.10 for Pandoc.

frontiers_article

Format for creating Frontiers journal articles. Adapted from https://www.frontiersin.org/about/author-guidelines.

glossa_article

Format for creating submissions to Glossa: a journal of general linguistics. Author Guidelines are available on www.glossa-journal.org. Template is adapted from https://github.com/guidovw/Glossalatex.

ims_article

Format for creating submissions to the Institute of Mathematical Statistics IMS journals and publications. Adapted from https://github.com/vtex-soft/texsupport.ims-aoas.

The argument journal accepts the acronym of any of the journals in IMS:

  • aap: The Annals of Applied Probability

  • aoas: The Annals of Applied Statistics

  • aop: The Annals of Probability

  • aos: The Annals of Statistics

  • sts: Statistical Science

informs_article

Format for creating submissions to INFORMS journals. Adapted from https://pubsonline.informs.org/authorportal/latex-style-files.

It requires a minimum version of 2.10 for Pandoc.

iop_article

Format for creating submissions to IOP journals. Adapted from https://publishingsupport.iopscience.iop.org/questions/latex-template/. Please read the guidelines at this link when preparing your article.

jasa_article

Format for creating submissions to the Journal of the Acoustical Society of America. Adapted from https://acousticalsociety.org/preparing-latex-manuscripts/.

lipics_article

Format for creating submissions to LIPIcs - Leibniz International Proceedings in Informatics - articles. Adapted from the official Instructions for Authors and the tagged LIPIcs author kit v2021.1.3, which contains lipics-v2021.cls v3.1.3. The kit is provided under The LaTeX Project Public License (LPPL), Version 1.3c.

Dagstuhl's official bibliography workflow uses BibTeX, raw LaTeX citations such as \cite{key}, and the fixed plainurl bibliography style. The citation_package argument remains user-selectable: "natbib" makes Pandoc translate Markdown citations to natbib commands, but this custom template does not load the unsupported natbib package; "default" uses Pandoc citeproc and is not the official BibTeX workflow. Structured related-version and supplement cite fields emit raw LaTeX citations and therefore require the BibTeX route; omit them when using citeproc. Other rmarkdown citation settings may require user-supplied LaTeX configuration. The template keeps plainurl fixed regardless of this argument.

pdfLaTeX is the default and XeLaTeX remains selectable. With the tagged class, the pdfa class option works with pdfLaTeX but not XeLaTeX. Existing drafts retain their local v2019 class and legacy thin-space metadata is normalized when rendering with pdfLaTeX.

lncs_article

Format for creating submissions to LNCS - Lecture Notes in Computer Science - articles. Adapted from the official Instructions for Authors at https://www.springer.com/gp/computer-science/lncs/conference-proceedings-guidelines and the template from the archive LaTeX2e+Proceedings+Templates+download.zip downloaded with version tag 2.21.

jedm_article

Format for creating Journal of Educational Data Mining (JEDM) articles. Adapted from https://jedm.educationaldatamining.org/index.php/JEDM/information/authors.

mnras_article

Format for creating an Monthly Notices of Royal Astronomical Society (MNRAS) Journal articles. Adapted from https://ras.ac.uk.

peerj_article

Format for creating submissions to The PeerJ Journal. This was adapted from the PeerJ Overleaf Template.

pihph_article

Format for creating submissions to the Papers in Historical Phonology (https://journals.ed.ac.uk/pihph/about/submissions). Adapted from https://github.com/pihph/templates. This format works well with latex_engine = "xelatex" and citation_package="biblatex", which are the default. It may not work correctly if you change these value. In that case, please open an issue and, a PR to contribute a change in the template.

plos_article

Format for creating submissions to PLOS journals. Adapted from https://journals.plos.org/ploscompbiol/s/latex.

pnas_article

Format for creating submissions to PNAS journals.

sage_article

Format for creating submissions to Sage Journals. Based on the official Sage Journals Class. Available at https://uk.sagepub.com/sites/default/files/sage_latex_template_4.zip.

Possible arguments for the YAML header are:

  • title title of the manuscript

  • runninghead short author list for header

  • author list of authors, containing name and num

  • address list containing num and org for defining author affiliations

  • corrauth corresponding author name and address

  • email correspondence email

  • abstract abstract, limited to 200 words

  • keywords keywords for the article

  • bibliography BibTeX .bib file name

  • classoption options of the sagej class

  • header-includes: custom additions to the header, before the \begin{document} statement

  • include-after: for including additional LaTeX code before the \end\{document} statement

sim_article

Format for creating submissions to Statistics in Medicine. Based on the official Statistics in Medicine at https://authorservices.wiley.com/author-resources/Journal-Authors/Prepare/new-journal-design.html.

This format uses xelatex by default as PDF engine to support the specific NJD fonts, per guideline.

Possible arguments for the YAML header are:

  • title title of the manuscript

  • author list of authors, containing name and num

  • address list containing num and org for defining author affiliations

  • presentaddress not sure what they mean with this

  • corres author and address for correspondence

  • authormark short author list for header

  • received, revised, accepted dates of submission, revision, and acceptance of the manuscript

  • abstract abstract, limited to 250 words

  • keywords up to 6 keywords

  • abbreviations, list of abbreviations and description separated by a comma

  • bibliography BibTeX .bib file

  • classoption options of the WileyNJD class

  • longtable set to true to include the longtable package, used by default from pandoc to convert markdown to LaTeX code

  • header-includes: custom additions to the header, before the \begin{document} statement

  • include-after: for including additional LaTeX code before the \end{document} statement

springer_article

This format was adapted from the Springer Macro package for Springer Journals.

trb_article

Format for creating submissions to the Transportation Research Board Annual Meeting. Adapted from https://www.overleaf.com/latex/templates/transportation-research-board-trb-latex-template/jkfndnnkkksw, which in turn is hosted at https://github.com/chiehrosswang/TRB_LaTeX_tex

wellcomeor_article

Format for creating submissions to Wellcome Open Research. Adapted from <overleaf.com/latex/templates/wellcome-open-research-article-template/hsmhhbpxvvbj>.

isba_article

Format for creating submissions to Bayesian analysis. Based on the official Bayesian analysis class. Template shows how to use this format as a base format for bookdown::pdf_book, but it can very well be used on its own (with limitations that figure referencing will not work). Note that the template sets md_extensions to exclude -autolink_bare_uris because otherwise author emails produce error

Possible arguments for the YAML header are:

  • title title of the manuscript. Shorter version of the title can be provided as runtitle.

  • classoption should equal ba or ba,preprint for supplementary article.“

  • author list of authors, containing firstname, lastname, email, url, affiliationref (as code) and footnoterefs (as list of codes)

  • affiliations list containing ref (code for defining author affiliations), institution name and address itself

  • footnotes a list of two-element entries: ref and text

  • abstract abstract, limited to 250 words

  • MSC2020primary, MSC2020primary lists of codes from MCS2020 database

  • keywords a list of keywords

  • supplements a list of entries with two elements title and description

  • doi DOI of the article

  • arxiv Arxiv id

  • acknowledgements acknowledgement text, limited to 250 words

  • bibliography BibTeX .bib file

  • longtable set to true to include the longtable package, used by default from pandoc to convert markdown to LaTeX code

  • header-includes: custom additions to the header, before the \begin{document} statement

  • include-after: for including additional LaTeX code before the \end{document} statement

Examples

if (FALSE) { # \dontrun{
rmarkdown::draft("MyArticle.Rmd", template = "acm", package = "rticles")
rmarkdown::draft("MyArticle.Rmd", template = "asa", package = "rticles")
} # }